type t =
  | Bool of bool
  | Int31       of int (** int for 32 bit arch *)
  | Int63       of int64 (** int for 64 bit arch *)
  | Int32       of int32
  | Int64       of int64
  | Nativeint32 of int32 (** natint for 32 bit arch *)
  | Nativeint64 of int64 (** natint for 64 bit arch *)
  | Float of float
  | Char of char
  | String of string
  | List  of t list
  | Array of t list
  | Variant      of string * t list (** Variants.  Note that Record style arguments are expressed as Varaint (Record ..) *)
  | Poly_variant of string * t list (** Polymorphic variants *)
  | Record of (string * t) list
  | Object of (string * t) list (** Object *)
  | Tuple of t list
  | Unit
  | Escaped of string (** Something outside of OCaml values *)
(*
  | Let_rec of string * t * t
  | Var of string
*)

type ocaml = t

val format
  : ?no_poly: bool (** If true, prints polymorphic variants and objects as variants and records *)
  -> ?raw_string: bool (** If true, strings are printed in non-escaped form. Probably useful to print non-ascii strings *)
  -> Format.formatter -> t -> unit

val format_with : ?no_poly: bool -> ?raw_string: bool -> ('a -> t) -> Format.formatter -> 'a -> unit
(** Same as [format] but prints a value of ['a] using the convert from ['a] to [t] *)

module Parser : sig
  
  type error = [ `Invalid_construct of Location.t
               | `Lexer of Location.t * Lexer.error
               | `Parser of Syntaxerr.error
	       | `Syntax_error of Location.t
               | `Exn of exn ]

  exception Error of error

  val loc_of_error : error -> Location.t
  val format_error : Format.formatter -> error -> unit

  (** They are not re-entrant, since OCaml's lexer is not. *)
  val from_lexbuf   : Lexing.lexbuf -> t list
  val from_channel  : in_channel -> t list
  val from_string   : string -> t list
  val from_function : (string -> int -> int) -> t list
end



